# Generated by Django 4.2.3 on 2023-08-03 16:05

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0086_rename_hoh_employment_healtheconomicshouseholdhead_hoh_employment_status_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient a citizen of this country?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_citizen",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient a citizen of this country?",
            ),
        ),
    ]
