# Generated by Django 4.1.2 on 2022-11-22 15:30

from django.db import migrations
import django_crypto_fields.fields.encrypted_char_field


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0006_remove_historicalpatientcall_willing_to_attend_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpatientlog",
            name="last_4_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of contact number",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientlog",
            name="last_4_hf_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of hf_identifier",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="last_4_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of contact number",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="last_4_hf_identifier",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                editable=False,
                help_text="auto-populated (Encryption: RSA local)",
                max_length=71,
                null=True,
                verbose_name="Last 4 digits of hf_identifier",
            ),
        ),
    ]
