# Generated by Django 4.2.5 on 2023-10-05 01:17

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0116_auto_20230920_0058"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnextappointment",
            name="allow_create_interim",
            field=models.BooleanField(
                default=False,
                help_text="Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.",
                verbose_name="Override date check?",
            ),
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="allow_create_interim",
            field=models.BooleanField(
                default=False,
                help_text="Override date check to allow the EDC to create an interim appointment if the date is within window period of the current appointment.",
                verbose_name="Override date check?",
            ),
        ),
    ]
