# Generated by Django 4.2.7 on 2023-12-05 20:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_ae", "0012_aefollowup_intecomm_ae_subject_a0869e_idx_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_a182a3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__ec3996_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_a1aa7e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="aetmg",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_753370_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreport",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__dc0ac5_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="deathreport",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_b7d689_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreport",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_d87c5d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_91820c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_ae_action__3601b2_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_73a21b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="deathreporttmg",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_d94467_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_ae_subject_152c93_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_ae_modifie_83f4ad_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_ae_user_mo_ab1ea2_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hospitalization",
            index=models.Index(
                fields=["subject_identifier", "site"], name="intecomm_ae_subject_7604a4_idx"
            ),
        ),
    ]
