ADULT = "adult"
ALONE = "alone"
APPT = "appt"
APPT_OTHER = "other_routine_appt"
CHILD = "child"
COMMUNITY_CLINIC = "community_clinic"
EXPENSIVE = "expensive"
GTE_3HRS = "gte_3hr"
HOME_REMEDIES = "home_remedies"
MAIN_EARNER = "main_earner"
MISSED_VISIT_ACTION = "missed_visit_action"
NURSE = "nurse"
PAID_WORK = "paid_work"
PROBLEMATIC = "problematic"
SITTING = "sitting"
STUDY_VISIT = "study_visit"
TOO_BUSY = "too_busy"
UNAVAILABLE = "unavailable"
UNIMPORTANT = "unimportant"
UNPAID_WORK = "unpaid_work"
VERTICAL = "vertical"
VIT_B_FOLIC_ACID = "vitamin_b_folic_acid"
