model_data = {
    "edc_lab.consignee": [
        {
            "name": "The INTECOMM Trial",
            "contact_name": "Sokoine Kivuyo",
            "address": "NIMR Tanzania",
            "postal_code": "-",
            "city": "Dar es Salaam",
            "state": None,
            "country": "Tanzania",
            "telephone": "+255763244779",
            "mobile": "+255763244779",
            "fax": None,
            "email": "sokoinele@yahoo.co.uk",
        }
    ]
}
