# Generated by Django 4.2.10 on 2024-02-22 05:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "intecomm_subject",
            "0144_rename_meds_prescribed_careseekingb_med_prescribed_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="careseekinga",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="hworker_duration",
            new_name="with_hcw_duration",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="hworker_duration",
            new_name="with_hcw_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="facility_visit_alt",
            new_name="missed_activities",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="facility_duration",
            new_name="visit_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="alt_lost_income",
            new_name="visit_lost_income",
        ),
    ]
