# Generated by Django 4.1.7 on 2023-06-27 15:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0032_patientgrouprando"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="consentrefusal",
            name="subject_identifier",
        ),
        migrations.RemoveField(
            model_name="consentrefusal",
            name="subject_identifier_aka",
        ),
        migrations.RemoveField(
            model_name="consentrefusal",
            name="subject_identifier_as_pk",
        ),
        migrations.RemoveField(
            model_name="historicalconsentrefusal",
            name="subject_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalconsentrefusal",
            name="subject_identifier_aka",
        ),
        migrations.RemoveField(
            model_name="historicalconsentrefusal",
            name="subject_identifier_as_pk",
        ),
        migrations.AlterField(
            model_name="consentrefusal",
            name="subject_screening",
            field=models.OneToOneField(
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_screening.subjectscreening",
            ),
        ),
    ]
