# Generated by Django 4.1.2 on 2023-01-27 01:09

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0008_historicalvitals_vitals_remove_indicators_site_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalvitals",
            name="bp_measured",
        ),
        migrations.RemoveField(
            model_name="historicalvitals",
            name="bp_not_measured_reason",
        ),
        migrations.RemoveField(
            model_name="vitals",
            name="bp_measured",
        ),
        migrations.RemoveField(
            model_name="vitals",
            name="bp_not_measured_reason",
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_one_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If first BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_one_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the first blood pressure reading done",
            ),
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_two_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If second BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="historicalvitals",
            name="bp_two_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                null=True,
                verbose_name="Was the second blood pressure reading done",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_one_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If first BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_one_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Was the first blood pressure reading done",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_two_not_taken_reason",
            field=models.CharField(
                blank=True,
                max_length=50,
                null=True,
                verbose_name="If second BP reading not done, please explain",
            ),
        ),
        migrations.AddField(
            model_name="vitals",
            name="bp_two_taken",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=15,
                null=True,
                verbose_name="Was the second blood pressure reading done",
            ),
        ),
    ]
