# Generated by Django 4.2.7 on 2023-12-05 20:41

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0064_alter_patientcall_options_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="patientlogreportprinthistory",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_891a97_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientlogreportprinthistory",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_7c6828_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectscreening",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_sc_subject_7056ed_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectscreening",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_824618_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectscreening",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_54a1bf_idx"
            ),
        ),
        migrations.AddConstraint(
            model_name="patientlog",
            constraint=models.UniqueConstraint(
                fields=("legal_name", "initials"),
                name="intecomm_screening_patientlog_legal_n_uniq",
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectscreening",
            constraint=models.UniqueConstraint(
                fields=("legal_name", "initials"),
                name="intecomm_screening_subjectscreening_legal_n_uniq",
            ),
        ),
    ]
