# Generated by Django 4.2.3 on 2023-07-20 03:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0009_subjectlocator_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="historicalsubjectlocator",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Subject Locator",
                "verbose_name_plural": "historical Subject Locators",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectlocator",
            options={
                "verbose_name": "Subject Locator",
                "verbose_name_plural": "Subject Locators",
            },
        ),
    ]
