# Generated by Django 5.0.4 on 2024-04-10 21:18

import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("intecomm_subject", "0156_careseekinga_accompany_alt_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="med_conditions",
            field=edc_model_fields.fields.custom_django_fields.ManyToManyField2(
                blank=True,
                limit_choices_to={"name__in": ["HIV", "dm", "htn", "OTHER"]},
                metadata="FOUTMEDCOND1",
                related_name="%(app_label)s_med_conditions_related",
                related_query_name="%(app_label)s_med_conditions_sources",
                to="intecomm_lists.conditions",
                verbose_name="What were the medicines were for?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="from a public facility, local pharmacy, traditional doctor, etc",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you seek advice or treatment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_advice",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="from a public facility, local pharmacy, traditional doctor, etc",
                max_length=15,
                metadata="FSEEK1",
                verbose_name="Did you seek advice or treatment?",
            ),
        ),
    ]
