# Generated by Django 5.0.3 on 2024-03-13 22:03

import django.core.validators
import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0151_alter_drugrefilldm_modifications_reason_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="careseekinga",
            old_name="visit_cost",
            new_name="care_visit_cost",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.RenameField(
            model_name="careseekinga",
            old_name="visit_reason",
            new_name="care_visit_reason",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="visit_duration",
            new_name="care_visit_duration",
        ),
        migrations.RenameField(
            model_name="careseekingb",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="visit_cost",
            new_name="care_visit_cost",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="visit_duration",
            new_name="care_visit_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekingb",
            old_name="visit_lost_income",
            new_name="care_visit_lost_income",
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="travel_time",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long did it take you to reach here?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FFACTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="wait_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWAITIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend waiting?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="with_hcw_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWORKTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend with the healthcare worker?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="travel_time",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FTRATIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long did it take you to reach here?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="visit_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FFACTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend during your visit today -- from arrival to this place until the end of your visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="wait_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWAITIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend waiting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="with_hcw_duration",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                help_text="something like 1h20m, 11h5m, etc",
                max_length=5,
                metadata="FWORKTIME1",
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How much time did you spend with the healthcare worker?",
            ),
        ),
    ]
