# Generated by Django 5.0 on 2024-01-10 22:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0018_subjectconsent_intecomm_co_modifie_45691e_idx_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectconsent",
            name="model_name",
            field=models.CharField(
                editable=False,
                help_text="label_lower of this model class. Will be different if instance has been added/edited via a proxy model",
                max_length=50,
                null=True,
                verbose_name="model",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectconsentug",
            name="model_name",
            field=models.CharField(
                editable=False,
                help_text="label_lower of this model class. Will be different if instance has been added/edited via a proxy model",
                max_length=50,
                null=True,
                verbose_name="model",
            ),
        ),
        migrations.AddField(
            model_name="subjectconsent",
            name="model_name",
            field=models.CharField(
                editable=False,
                help_text="label_lower of this model class. Will be different if instance has been added/edited via a proxy model",
                max_length=50,
                null=True,
                verbose_name="model",
            ),
        ),
    ]
