# Generated by Django 4.2.3 on 2023-07-11 02:35

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0053_remove_historicalhivreview_arv_initiated_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalhtnreview",
            name="dia_blood_pressure",
        ),
        migrations.RemoveField(
            model_name="historicalhtnreview",
            name="sys_blood_pressure",
        ),
        migrations.RemoveField(
            model_name="htnreview",
            name="dia_blood_pressure",
        ),
        migrations.RemoveField(
            model_name="htnreview",
            name="sys_blood_pressure",
        ),
    ]
