# Generated by Django 4.1.2 on 2022-11-20 22:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0001_initial"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="healthtalklog",
            name="unique_lower_name_report_date",
        ),
        migrations.RemoveField(
            model_name="healthtalklog",
            name="health_facility_type",
        ),
        migrations.RemoveField(
            model_name="healthtalklog",
            name="health_facility_type_other",
        ),
        migrations.RemoveField(
            model_name="historicalhealthtalklog",
            name="health_facility_type",
        ),
        migrations.RemoveField(
            model_name="historicalhealthtalklog",
            name="health_facility_type_other",
        ),
        migrations.AddConstraint(
            model_name="healthtalklog",
            constraint=models.UniqueConstraint(
                models.F("health_facility"),
                models.F("report_date"),
                name="unique_health_facility_report_date",
                violation_error_message="Only one report expected per facility per day.",
            ),
        ),
    ]
