{% extends 'intecomm_edc/bootstrap3/base.html' %}
{% load static edc_dashboard_extras %}

{% block main %}

<style>

.bg-1 {
    background-color: #428bca; /* dark blue */
    color: #ffffff;
}
.bg-2 {
    background-color: #5bc0de; /* light Blue */
    color: #ffffff;
}
.bg-3 {
    background-color: #f9f9f9; /* White */
    color: #555555;
}

</style>

{{ block.super }}



<div class="row">

  <div class="col-sm-4">&nbsp;</div>
  <div class="col-sm-4">
    <div class="panel panel-default">
      <div class="panel-heading"><i class="fas fa-users-between-lines fa-lg fa-fw" aria-hidden="true"></i> Community-care at {{ site_title|default:request.site.name|title }}</div>
      <div class="list-group">
        <a id="home_list_group_home" href="{% url 'home_url' %}" class="list-group-item"><i class="fas fa-reply fa-1x fa-fw" aria-hidden="true"></i> Home</a>
      {% if perms.edc_subject_dashboard.view_subject_listboard %}
        <a id="home_list_group_subject_listboard" href="{% url subject_listboard_url|default:'subject_listboard_url_cannot_be_none' %}" class="list-group-item"><i class="fas fa-user-circle fa-lg fa-fw"></i>&nbsp;&nbsp;&nbsp;
          Subjects</a>
      {% endif %}
      {% if perms.edc_review_dashboard.view_subject_review_listboard %}
        <a id="home_list_group_subject_review_listboard" href="{% url subject_review_listboard_url|default:'subject_review_listboard_url_cannot_be_none' %}" class="list-group-item"><i class="fas fa-calendar fa-lg fa-fw"></i>&nbsp;&nbsp;&nbsp;Subject Review</a>
      {% endif %}
      {% if perms.edc_locator.view_subjectlocator %}
        <a id="home_list_group_subject_locator" href="{% url 'intecomm_prn_admin:intecomm_prn_subjectlocator_changelist' %}" class="list-group-item"><i class="fas fa-location-dot fa-lg fa-fw"></i>&nbsp;&nbsp;&nbsp;Subject Locator</a>
      {% endif %}
      {% if perms.edc_adverse_event.nav_ae_section %}
        <a id="home_list_group_ae" href="{% url 'edc_adverse_event:ae_home_url' %}" class="list-group-item"><i class="fas fa-heartbeat fa-lg fa-fw"></i>&nbsp;&nbsp;&nbsp;Adverse events</a>
      {% endif %}
      {% if perms.edc_adverse_event.nav_tmg_section %}
        <a id="home_list_group_aetmg" href="{% url 'edc_adverse_event:tmg_home_url' %}" class="list-group-item"><i class="fas fa-heartbeat fa-lg fa-fw"></i>&nbsp;&nbsp;&nbsp;TMG Reports</a>
      {% endif %}
      </div>
    </div>
  </div>
  <div class="col-sm-4">&nbsp;
  </div>
</div>



{% endblock main %}
