# Generated by Django 4.2.3 on 2023-07-12 23:24

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0054_remove_historicalhtnreview_dia_blood_pressure_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="drugrefilldm",
            old_name="return_in_days",
            new_name="rx_days",
        ),
        migrations.RenameField(
            model_name="drugrefillhiv",
            old_name="return_in_days",
            new_name="rx_days",
        ),
        migrations.RenameField(
            model_name="drugrefillhtn",
            old_name="return_in_days",
            new_name="rx_days",
        ),
        migrations.RenameField(
            model_name="historicaldrugrefilldm",
            old_name="return_in_days",
            new_name="rx_days",
        ),
        migrations.RenameField(
            model_name="historicaldrugrefillhiv",
            old_name="return_in_days",
            new_name="rx_days",
        ),
        migrations.RenameField(
            model_name="historicaldrugrefillhtn",
            old_name="return_in_days",
            new_name="rx_days",
        ),
    ]
