# Generated by Django 4.2.1 on 2023-07-06 02:18

import django.db.models.manager
import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0044_alter_historicalpatientlog_site_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="consentrefusal",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Consent Refusal",
                "verbose_name_plural": "Consent Refusals",
            },
        ),
        migrations.AlterModelOptions(
            name="patientcall",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ["report_datetime"],
                "verbose_name": "Patient Call",
                "verbose_name_plural": "Patient Calls",
            },
        ),
        migrations.AlterModelOptions(
            name="patientlogreportprinthistory",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Patient Log Report Print History",
                "verbose_name_plural": "Patient Log Report Print History",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectscreening",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Subject Screening",
                "verbose_name_plural": "Subject Screening",
            },
        ),
        migrations.AlterModelManagers(
            name="consentrefusal",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
    ]
