# Generated by Django 5.0.4 on 2024-04-10 21:49

import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0159_careseekingb_missed_activities_other_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="careseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcareseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany_alt",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACMPACT1",
                verbose_name="If those accompanying you were not attending your last/most recent visit with you, what would they have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="accompany_alt",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACMPACT1",
                verbose_name="If those accompanying you were not attending your last/most recent visit with you, what would they have been doing?",
            ),
        ),
    ]
