from edc_constants.constants import NOT_APPLICABLE, OTHER

RESPONDENT_CHOICES = (
    ("patient", "Patient"),
    ("family", "Family"),
    ("friend", "friend"),
    (OTHER, "other"),
    (NOT_APPLICABLE, "Not applicable"),
)
