# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models
import edc_utils.date


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_group", "0016_alter_communitycarelocation_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="communitycarelocation",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Community Care Location",
                "verbose_name_plural": "Community Care Locations",
            },
        ),
        migrations.AlterModelOptions(
            name="patientfollowupcall",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Patient Followup Call",
                "verbose_name_plural": "Patient Followup Calls",
            },
        ),
        migrations.AlterModelOptions(
            name="patientgroup",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Patient Group",
                "verbose_name_plural": "Patient Groups",
            },
        ),
        migrations.AlterModelOptions(
            name="patientgroupappointment",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Patient Group Appointment",
                "verbose_name_plural": "Patient Group Appointments",
            },
        ),
        migrations.AlterModelOptions(
            name="patientgroupmeeting",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Patient Group Meeting",
                "verbose_name_plural": "Patient Groups Meeting",
            },
        ),
        migrations.AddField(
            model_name="communitycarelocation",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="communitycarelocation",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientgroup",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patientgroupappointment",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patientgroupappointment",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patientgroupmeeting",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patientgroupmeeting",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientfollowupcall",
            name="report_datetime",
            field=models.DateTimeField(db_index=True, default=edc_utils.date.get_utcnow),
        ),
        migrations.AlterField(
            model_name="patientfollowupcall",
            name="report_datetime",
            field=models.DateTimeField(db_index=True, default=edc_utils.date.get_utcnow),
        ),
        migrations.AddIndex(
            model_name="communitycarelocation",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_gr_modifie_9695bc_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="communitycarelocation",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_gr_user_mo_b4b5cb_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="patientfollowupcall",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_gr_modifie_55b38c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientfollowupcall",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_gr_user_mo_b1771e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="patientgroup",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_gr_modifie_709aa8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientgroup",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_gr_user_mo_88354b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="patientgroup",
            index=models.Index(
                fields=["group_identifier", "status"],
                name="intecomm_gr_group_i_d392d3_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="patientgroupappointment",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_gr_modifie_bc2cdb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientgroupappointment",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_gr_user_mo_aaafcb_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="patientgroupmeeting",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_gr_modifie_12dbed_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientgroupmeeting",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_gr_user_mo_746ccc_idx",
            ),
        ),
    ]
