# Generated by Django 4.2.4 on 2023-08-26 22:51

import django.contrib.sites.managers
from django.db import migrations

import intecomm_consent.models.subject_consent


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0012_alter_historicalsubjectconsent_device_created_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="SubjectConsentUg",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("intecomm_consent.subjectconsent",),
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", intecomm_consent.models.subject_consent.ConsentObjectsManager()),
            ],
        ),
    ]
