# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_lists",
            "0009_alter_arvdrugs_options_alter_arvregimens_options_and_more",
        ),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="arvdrugs",
            name="intecomm_li_name_b55bdc_idx",
        ),
        migrations.RemoveIndex(
            model_name="arvregimens",
            name="intecomm_li_name_dd4128_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicalwithdrawalreasons",
            name="intecomm_li_name_bfca7f_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicservices",
            name="intecomm_li_name_deec16_idx",
        ),
        migrations.RemoveIndex(
            model_name="conditions",
            name="intecomm_li_name_b9ae61_idx",
        ),
        migrations.RemoveIndex(
            model_name="consentrefusalreasons",
            name="intecomm_li_name_04461e_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmmanagement",
            name="intecomm_li_name_edefb8_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmtreatments",
            name="intecomm_li_name_596944_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugdispensaries",
            name="intecomm_li_name_2312cd_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugdispensers",
            name="intecomm_li_name_4d9885_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugpaysources",
            name="intecomm_li_name_b764fd_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthadvisors",
            name="intecomm_li_name_dd5fb2_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthfacilitytypes",
            name="intecomm_li_name_af9934_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthinterventiontypes",
            name="intecomm_li_name_5a8bd1_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthservices",
            name="intecomm_li_name_b9dd17_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthtalkconditions",
            name="intecomm_li_name_9d805e_idx",
        ),
        migrations.RemoveIndex(
            model_name="healthtalktypes",
            name="intecomm_li_name_dae47f_idx",
        ),
        migrations.RemoveIndex(
            model_name="htnmanagement",
            name="intecomm_li_name_17a894_idx",
        ),
        migrations.RemoveIndex(
            model_name="htntreatments",
            name="intecomm_li_name_ebbf62_idx",
        ),
        migrations.RemoveIndex(
            model_name="laboratorytests",
            name="intecomm_li_name_3dad94_idx",
        ),
        migrations.RemoveIndex(
            model_name="locationtypes",
            name="intecomm_li_name_f97934_idx",
        ),
        migrations.RemoveIndex(
            model_name="medicationshortagereasons",
            name="intecomm_li_name_ad571f_idx",
        ),
        migrations.RemoveIndex(
            model_name="nonadherencereasons",
            name="intecomm_li_name_a7a6a5_idx",
        ),
        migrations.RemoveIndex(
            model_name="offstudyreasons",
            name="intecomm_li_name_aabb4d_idx",
        ),
        migrations.RemoveIndex(
            model_name="refillconditions",
            name="intecomm_li_name_085d7f_idx",
        ),
        migrations.RemoveIndex(
            model_name="rxmodificationreasons",
            name="intecomm_li_name_c1233d_idx",
        ),
        migrations.RemoveIndex(
            model_name="rxmodifications",
            name="intecomm_li_name_3f4bd2_idx",
        ),
        migrations.RemoveIndex(
            model_name="screeningrefusalreasons",
            name="intecomm_li_name_1da54a_idx",
        ),
        migrations.RemoveIndex(
            model_name="subjectvisitmissedreasons",
            name="intecomm_li_name_12d94d_idx",
        ),
        migrations.RemoveIndex(
            model_name="toxicitywithdrawalreasons",
            name="intecomm_li_name_30f17d_idx",
        ),
        migrations.RemoveIndex(
            model_name="transferreasons",
            name="intecomm_li_name_eb67c1_idx",
        ),
        migrations.RemoveIndex(
            model_name="transportchoices",
            name="intecomm_li_name_bea030_idx",
        ),
        migrations.RemoveIndex(
            model_name="visitreasons",
            name="intecomm_li_name_59f9c6_idx",
        ),
    ]
