# Generated by Django 5.0.4 on 2024-04-10 21:36

import edc_model_fields.fields.other_charfield
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0158_alter_careseekingb_med_collected_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="careseekingb",
            name="missed_activities_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FMEDOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalcareseekingb",
            name="missed_activities_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FMEDOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]
