# Generated by Django 5.0.4 on 2024-04-17 03:36

import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0176_rename_seek_advice_careseekingb_accessed_care_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACMP1",
                null=True,
                verbose_name="Who accompanied you to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="care_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("inpatient", "Inpatient (stayed overnight for 1 or more nights)"),
                    ("both", "Both"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKTYPE1",
                verbose_name="If yes, what type of care was this?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACMP1",
                null=True,
                verbose_name="Who accompanied you to your last/most recent visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="care_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("inpatient", "Inpatient (stayed overnight for 1 or more nights)"),
                    ("both", "Both"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKTYPE1",
                verbose_name="If yes, what type of care was this?",
            ),
        ),
    ]
