# Generated by Django 4.2.3 on 2023-08-07 22:57

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0094_alter_healtheconomicsproperty_land_surface_area_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="bedrooms",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many rooms are used for sleeping in your dwelling?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="beds",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many beds does your dwelling have in total?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsassets",
            name="rooms",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="bedrooms",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many rooms are used for sleeping in your dwelling?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="beds",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many beds does your dwelling have in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsassets",
            name="rooms",
            field=models.IntegerField(
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(30),
                ],
                verbose_name="How many rooms does your dwelling have in total, without counting the bathrooms/ toilets or hallways/passageways?",
            ),
        ),
    ]
