# Generated by Django 4.1.2 on 2022-12-01 03:01

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0004_alter_historicalsubjectconsent_familiar_name_and_more"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="subjectconsent",
            name="unique_consent_subject_id_and_version",
        ),
        migrations.RemoveConstraint(
            model_name="subjectconsent",
            name="unique_consent_subject_id_screening_id",
        ),
        migrations.RemoveConstraint(
            model_name="subjectconsent",
            name="unique_consent_name_dob_initials",
        ),
        migrations.AlterUniqueTogether(
            name="subjectconsent",
            unique_together={
                ("subject_identifier", "version"),
                ("familiar_name", "dob", "initials", "version"),
                ("subject_identifier", "screening_identifier"),
            },
        ),
    ]
