{% if change_list_href %}
<a id="patient_log_changelist_{{ screening_identifier }}"
 	title="{{ title }}"  class="btn btn-default btn-sm" {% if perms.intecomm_screening.view_patientlog or perms.intecomm_screening.change_patientlog %}
   href="{{ change_list_href }}"{% else %}disabled{% endif %}>
  <i class="fas fa-person-circle-plus fa-fw"></i>
</a>
{% endif  %}
