{% load i18n %}
<H5><B><span style="color:orange">{% trans "Interviewer to read" %}</span></B></H5>
<p style="background-color: yellow; padding: 10px;">{% trans "I would like to ask you some questions to understand more about your visit today." %}
  <BR>{% trans "This will include questions on your travel here, the time spent on this visit and any costs you may have incurred." %}
</p>
