# Generated by Django 4.2.3 on 2023-07-26 14:58

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        # ("intecomm_facility", "0002_alter_healthfacility_device_created_and_more"),
        ("intecomm_screening", "0049_healthfacility"),
    ]

    operations = [
        migrations.AddField(
            model_name="healthtalklog",
            name="health_facility",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_facility.healthfacility",
                verbose_name="Health facility",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealthtalklog",
            name="health_facility",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="intecomm_facility.healthfacility",
                verbose_name="Health facility",
            ),
        ),
        migrations.AddField(
            model_name="idenfifierformat",
            name="health_facility",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_facility.healthfacility",
                verbose_name="Health facility",
            ),
        ),
    ]
