# Generated by Django 4.2.7 on 2023-12-05 20:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0063_alter_consentrefusal_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="patientcall",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "verbose_name": "Patient Call",
                "verbose_name_plural": "Patient Calls",
            },
        ),
        migrations.AddIndex(
            model_name="consentrefusal",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_810e6d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="consentrefusal",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_5255fb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalklog",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_d8ef96_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalklog",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_eea0dd_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="oldhealthfacility",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_2d68e8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="oldhealthfacility",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_6c3bd9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientcall",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_4901ee_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientcall",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_8f9412_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientlog",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_sc_modifie_fa49a4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="patientlog",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_sc_user_mo_08d139_idx"
            ),
        ),
    ]
