# Generated by Django 4.1.7 on 2023-09-18 11:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0015_historicalsubjectconsentug"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                    ("ry", "Runyakitara"),
                    ("lg", "Ganda"),
                    ("rny", "Runyankore"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentug",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                    ("ry", "Runyakitara"),
                    ("lg", "Ganda"),
                    ("rny", "Runyankore"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                    ("ry", "Runyakitara"),
                    ("lg", "Ganda"),
                    ("rny", "Runyankore"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
    ]
