# Generated by Django 5.0.4 on 2024-04-10 21:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0012_visitreasons_custom_name"),
        ("intecomm_screening", "0069_subjectscreeningtz_historicalsubjectscreeningtz"),
    ]

    operations = [
        migrations.AlterField(
            model_name="patientlog",
            name="conditions",
            field=models.ManyToManyField(
                limit_choices_to={"name__in": ["HIV", "dm", "htn"]},
                to="intecomm_lists.conditions",
                verbose_name="Diagnoses",
            ),
        ),
    ]
