# Generated by Django 5.0.4 on 2024-04-10 17:41

import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0154_careseekinga_missed_activities_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekinga",
            name="referral_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("public_clinic", "Public facility below tertiary level"),
                    ("private_clinic", "Private clinic"),
                    ("private_dx_facility", "Private diagnostic facility"),
                    ("ngo_clinic", "NGO clinic"),
                    ("public_hospital", "Public Hospital/tertiary facility"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFAC1",
                verbose_name="What type of facility have you been referred to?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="referral_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("inpatient", "Inpatient"),
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFTYPE1",
                verbose_name="Is this for inpatient or outpatient care?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="referral_facility",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("public_clinic", "Public facility below tertiary level"),
                    ("private_clinic", "Private clinic"),
                    ("private_dx_facility", "Private diagnostic facility"),
                    ("ngo_clinic", "NGO clinic"),
                    ("public_hospital", "Public Hospital/tertiary facility"),
                    ("private_hospital", "Private hospital"),
                    ("pharmacy", "Pharmacy"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFAC1",
                verbose_name="What type of facility have you been referred to?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="referral_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("inpatient", "Inpatient"),
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FREFTYPE1",
                verbose_name="Is this for inpatient or outpatient care?",
            ),
        ),
    ]
