# Generated by Django 4.2.7 on 2023-12-05 20:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0013_endofstudy_locale_created_endofstudy_locale_modified_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__f3bf58_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_f05824_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_89a34d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site", "id"],
                name="intecomm_pr_subject_96eaef_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_pr_subject_9a445d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__415159_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_dbd0f3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_f0e202_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_subject_51b057_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__c60fdc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_946b96_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_593cbf_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=[
                    "id",
                    "subject_identifier",
                    "action_identifier",
                    "offschedule_datetime",
                    "site",
                ],
                name="intecomm_pr_id_674324_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_subject_86628b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__3f16f3_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_673c82_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_8df27b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=[
                    "id",
                    "subject_identifier",
                    "action_identifier",
                    "offschedule_datetime",
                    "site",
                ],
                name="intecomm_pr_id_2e2c54_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_subject_63aaaf_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_9288ba_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_1e1ee6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_subject_2dcd56_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_322d8f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_adb6ab_idx"
            ),
        ),
    ]
