# Generated by Django 5.0.1 on 2024-02-22 01:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0011_accompanied_moneysources_travelmethods"),
    ]

    operations = [
        migrations.AddField(
            model_name="visitreasons",
            name="custom_name",
            field=models.CharField(
                blank=True,
                help_text="A custom name/value to use on export instead of or in addition to `name`",
                max_length=25,
                null=True,
            ),
        ),
    ]
