# Generated by Django 5.0.4 on 2024-04-16 20:40

import django.core.validators
import edc_model_fields.fields.custom_django_fields
import edc_model_fields.fields.other_charfield
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0174_remove_careseekinga_care_visit_lost_income_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="careseekinga",
            name="wait_duration",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekinga",
            name="wait_duration",
        ),
        migrations.AddField(
            model_name="careseekingb",
            name="accompany_alt_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FOUTACMPACTOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalcareseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                ],
                max_length=25,
                metadata="FOUTACMP1",
                null=True,
                verbose_name="Who accompanied you here today?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcareseekingb",
            name="accompany_alt_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FOUTACMPACTOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.RemoveField(
            model_name="careseekingb",
            name="accompany",
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you to your last/most recent visit",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If NO, STOP and SAVE.",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="outpatient_visits",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUT1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(10),
                ],
                verbose_name="If yes and OUTPATIENT or BOTH, how many outpatient visits in total?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_care_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("inpatient", "Inpatient (stayed overnight for 1 or more nights"),
                    ("both", "Both"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKTYPE1",
                verbose_name="If yes, what type of care was this?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_done",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="select YES even if done elsewhere / another facility",
                max_length=25,
                metadata="FOUTTESTDONE1",
                verbose_name="Were the tests performed?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you to your last/most recent visit",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If NO, STOP and SAVE.",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="outpatient_visits",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUT1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(10),
                ],
                verbose_name="If yes and OUTPATIENT or BOTH, how many outpatient visits in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_care_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("inpatient", "Inpatient (stayed overnight for 1 or more nights"),
                    ("both", "Both"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKTYPE1",
                verbose_name="If yes, what type of care was this?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_done",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="select YES even if done elsewhere / another facility",
                max_length=25,
                metadata="FOUTTESTDONE1",
                verbose_name="Were the tests performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.AddField(
            model_name="careseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                ],
                max_length=25,
                metadata="FOUTACMP1",
                null=True,
                verbose_name="Who accompanied you here today?",
            ),
        ),
    ]
