{% extends "edc_model_admin/admin/change_list.html" %}
{% load i18n admin_urls static admin_list edc_admin_modify %}
{% load edc_sites_extras %}

{% block object-tools-items %}
  <li>
    <a href="{% url "screen_group_url" %}" class="changelink">Home</a>
  </li>
  <li>
    <a href="#" class="changelink"  style="background-color: black;">
      Consent
    </a>
  </li>
  <li>
    <a href="{% url "intecomm_dashboard:screening_listboard_url" %}" class="changelink">
      Screening
    </a>
  </li>
  <li>
  {% if request|country == "uganda" %}
    <a href="{% url "intecomm_screening_admin:intecomm_screening_patientlogug_changelist" %}" class="changelink">
  {% else %}
    <a href="{% url "intecomm_screening_admin:intecomm_screening_patientlog_changelist" %}" class="changelink">
  {% endif %}
      Patients
    </a>
  </li>
  <li>
    <a href="{% url "intecomm_screening_admin:intecomm_screening_patientgroup_changelist" %}" class="changelink">
      Groups
    </a>
  </li>
  <li>
    <a href="{% url "intecomm_screening_admin:intecomm_screening_patientcall_changelist" %}" class="changelink">
      Calls
    </a>
  </li>
  <li>
    <a href="{% url "intecomm_screening_admin:intecomm_screening_healthtalklog_changelist" %}" class="changelink">
      Talks
    </a>
  </li>
  <li>
    <a href="{% url "intecomm_facility_admin:intecomm_facility_healthfacility_changelist" %}" class="changelink">
      Facilities
    </a>
  </li>
  <li>
  {% if request|country == "uganda" %}
    <a href="{% url "intecomm_consent_admin:intecomm_consent_subjectconsentug_add" %}" class="addlink" style="background-color: darkorange;">Add</a>
  {% else %}
    <a href="{% url "intecomm_consent_admin:intecomm_consent_subjectconsenttz_add" %}" class="addlink" style="background-color: darkorange;">Add</a>
  {% endif %}
</li>
{% endblock %}
